# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import AppCommandContext, DataNavigator, Properties
from .Toolbar import IToolbarsManager, ToolbarsManagerBase
from .UIScriptIF import IUIState

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisForm

class DockManager(Agilent.MassHunter.Quantitative.UIModel.IDockManager):  # Class
    def __init__(
        self, manager: Infragistics.Win.UltraWinDock.UltraDockManager
    ) -> None: ...

    ActivePane: Agilent.MassHunter.Quantitative.UIModel.IDockPane  # readonly

    def ControlPaneExists(self, paneId: str) -> bool: ...
    def GetPane(
        self, paneId: str
    ) -> Agilent.MassHunter.Quantitative.UIModel.IDockPane: ...

class DockPane(Agilent.MassHunter.Quantitative.UIModel.IDockPane):  # Class
    Control: System.Windows.Forms.Control  # readonly

class MainForm(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    Agilent.MassHunter.Quantitative.UIModel.IMainWindow,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self, navigator: DataNavigator) -> None: ...

    CalCurvePane: Agilent.MassHunter.Quantitative.UIModel.ICalCurvePane  # readonly
    ChromSpecPane: Agilent.MassHunter.Quantitative.UIModel.IChromSpecPane  # readonly
    CommandContext: AppCommandContext  # readonly
    DataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator  # readonly
    DockManager: Agilent.MassHunter.Quantitative.UIModel.IDockManager  # readonly
    MethodErrorListPane: (
        Agilent.MassHunter.Quantitative.UIModel.IMethodErrorListPane
    )  # readonly
    MethodTablePane: (
        Agilent.MassHunter.Quantitative.UIModel.IMethodTablePane
    )  # readonly
    MethodTasksPane: (
        Agilent.MassHunter.Quantitative.UIModel.IMethodTasksPane
    )  # readonly
    MetricsPlotPane: (
        Agilent.MassHunter.Quantitative.UIModel.IMetricsPlotPane
    )  # readonly
    PresentationState: (
        Agilent.MassHunter.Quantitative.UIModel.IPresentationState
    )  # readonly
    SampleDataPane: Agilent.MassHunter.Quantitative.UIModel.ISampleDataPane  # readonly
    ScriptPane: Agilent.MassHunter.Quantitative.UIModel.IScriptPane  # readonly
    StatusBar: Agilent.MassHunter.Quantitative.UIModel.IStatusBar  # readonly
    ToolbarsManager: IToolbarsManager  # readonly
    UIState: IUIState
    WorktablePane: Agilent.MassHunter.Quantitative.UIModel.IWorktablePane  # readonly

    def RegisterCustomPane(
        self,
        register: bool,
        key: str,
        pane: Agilent.MassHunter.Quantitative.UIModel.ICustomPane,
    ) -> None: ...
    def ActivatePane(self, paneKey: str) -> None: ...
    def CustomPaneExists(self, key: str) -> bool: ...
    def ForceClose(self) -> None: ...
    def ResetLayout(self) -> None: ...
    def SetPaneVisible(self, paneKey: str, visible: bool) -> None: ...
    def ShowMethodErrorListPane(self) -> None: ...
    def InitTools(self, assembly: str) -> None: ...
    def IsInModalState(self) -> bool: ...
    def LayoutPanes(self, pattern: int) -> None: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def ValidateMethod(self, alwaysShowPane: bool) -> None: ...
    def InitDockState(self) -> bool: ...
    def MaximizePane(self, paneKey: str) -> None: ...
    def IsPaneVisible(self, paneKey: str) -> bool: ...
    def GetCustomPane(
        self, key: str
    ) -> Agilent.MassHunter.Quantitative.UIModel.ICustomPane: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def ShowWindow(self) -> None: ...
    def ShowAboutBox(self) -> None: ...
    def ComplianceInitialized(self) -> None: ...

    HandleAboutBox: System.EventHandler  # Event
    MethodTablePaneCreated: System.EventHandler  # Event

class MainWindowTitleHandler(System.IDisposable):  # Class
    def __init__(
        self,
        state: Agilent.MassHunter.Quantitative.UIModel.IPresentationState,
        mainWindow: Agilent.MassHunter.Quantitative.UIModel.IMainWindow,
    ) -> None: ...
    def Dispose(self) -> None: ...
    def UpdateTitle(self) -> None: ...

class QuantCR(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

class ToolbarsManager(
    System.ComponentModel.ISupportInitialize,
    System.IDisposable,
    ToolbarsManagerBase,
    System.Windows.Forms.IMessageFilter,
    IToolbarsManager,
):  # Class
    ApplicationType: str  # readonly
    InstrumentType: str  # readonly

    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def RegisterScriptToolHandler(
        self, tool: str, module: str, setState: str, execute: str
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils

class ContainsOperator(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class EqualOperator(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class FindOperator:  # Class
    def Match(self, value1: Any, value2: Any) -> bool: ...
    @staticmethod
    def Create(
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
    ): ...
    @staticmethod
    def RequiresValue(
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType,
    ) -> bool: ...

class FindOperatorType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Contains: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType
    ) = ...  # static # readonly
    Equal: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType
    ) = ...  # static # readonly
    Greater: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType
    ) = ...  # static # readonly
    GreaterEqual: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType
    ) = ...  # static # readonly
    IsNull: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType
    ) = ...  # static # readonly
    Less: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType
    ) = ...  # static # readonly
    LessEqual: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType
    ) = ...  # static # readonly
    NotContains: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType
    ) = ...  # static # readonly
    NotEqual: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType
    ) = ...  # static # readonly
    NotNull: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType
    ) = ...  # static # readonly

class GreaterEqualOperator(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class GreaterOperator(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class IsNullOperator(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class LessEqualOperator(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class LessOperator(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class NotContainsOperator(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class NotEqualOperator(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class NotNullOperator(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2

class ColorComboBox(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.OwnerDrawComboBox,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
):  # Class
    def __init__(self) -> None: ...

    SelectedColor: Optional[System.Drawing.Color]  # readonly

    def Initialize(
        self,
        items: List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.ColorComboBoxItem
        ],
    ) -> None: ...
    def SetSelectedColor(self, color: System.Drawing.Color) -> None: ...

class ColorComboBoxItem(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.OwnerDrawComboBoxItem
):  # Class
    def __init__(self, color: System.Drawing.Color, text: str) -> None: ...

    Color: System.Drawing.Color
    Text: str

    def Draw(
        self,
        parent: System.Windows.Forms.Control,
        e: System.Windows.Forms.DrawItemEventArgs,
    ) -> None: ...
    @staticmethod
    def GetStandardColorItems() -> (
        List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.ColorComboBoxItem
        ]
    ): ...

class ColorListDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(
        self,
        defaultColors: Iterable[System.Drawing.Color],
        colors: Iterable[System.Drawing.Color],
    ) -> None: ...
    def GetColors(self) -> List[System.Drawing.Color]: ...

class ColumnGroupGrid(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    DataGridView: System.Windows.Forms.DataGridView  # readonly
    DisplayRectangle: System.Drawing.Rectangle  # readonly

    def AddGroup(self, group: str, caption: str) -> None: ...
    def GroupExists(self, group: str) -> bool: ...
    def GetColumnGroup(self, column: str) -> str: ...
    def ClearGroups(self) -> None: ...
    def SetColumnGroup(self, column: str, group: str) -> None: ...
    def GetGroupCaption(self, group: str) -> str: ...

class DataGridViewPathNameCell(
    System.IDisposable, System.ICloneable, System.Windows.Forms.DataGridViewTextBoxCell
):  # Class
    def PositionEditingControl(
        self,
        setLocation: bool,
        setSize: bool,
        cellBounds: System.Drawing.Rectangle,
        cellClip: System.Drawing.Rectangle,
        cellStyle: System.Windows.Forms.DataGridViewCellStyle,
        singleVerticalBorderAdded: bool,
        singleHorizontalBorderAdded: bool,
        isFirstDisplayedColumn: bool,
        isFirstDisplayedRow: bool,
    ) -> None: ...

class FontFamilyComboBox(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.OwnerDrawComboBox,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
):  # Class
    def __init__(self) -> None: ...

    SelectedFont: System.Drawing.FontFamily

    def Initialize(
        self,
        items: List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.FontFamilyComboBoxItem
        ],
    ) -> None: ...

class FontFamilyComboBoxItem(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.OwnerDrawComboBoxItem
):  # Class
    def __init__(self, fontFamily: System.Drawing.FontFamily) -> None: ...

    FontFamily: System.Drawing.FontFamily  # readonly

    def Draw(
        self,
        parent: System.Windows.Forms.Control,
        e: System.Windows.Forms.DrawItemEventArgs,
    ) -> None: ...
    @staticmethod
    def GetStandardItems() -> (
        List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.FontFamilyComboBoxItem
        ]
    ): ...

class HatchStyleComboBox(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.OwnerDrawComboBox,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
):  # Class
    def __init__(self) -> None: ...

    SelectedHatchStyle: Optional[System.Drawing.Drawing2D.HatchStyle]

class HatchStyleComboBoxItem(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.OwnerDrawComboBoxItem
):  # Class
    def __init__(
        self, hs: Optional[System.Drawing.Drawing2D.HatchStyle], text: str
    ) -> None: ...

    HatchStyle: Optional[System.Drawing.Drawing2D.HatchStyle]
    Text: str

    def Draw(
        self,
        parent: System.Windows.Forms.Control,
        e: System.Windows.Forms.DrawItemEventArgs,
    ) -> None: ...

class IPropertyPage(object):  # Interface
    Control: System.Windows.Forms.Control  # readonly
    DisplayName: str
    IsDirty: bool  # readonly

    def SetActive(self) -> None: ...
    def DoDefault(self) -> None: ...
    def Apply(self) -> None: ...

    PageChanged: System.EventHandler  # Event

class IWizard(object):  # Interface
    ActivePage: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IWizardPage
    ActivePageIndex: int
    Count: int  # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IWizardPage: ...
    Title: str

    def AddPages(
        self,
        pages: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IWizardPage
        ],
    ) -> None: ...
    def SetButtons(
        self,
        buttons: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.WizardButtons,
    ) -> None: ...
    def AddPage(
        self,
        page: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IWizardPage,
    ) -> None: ...

class IWizardPage(System.IDisposable):  # Interface
    Control: System.Windows.Forms.Control  # readonly
    Description: str  # readonly
    PageSize: System.Drawing.Size  # readonly
    Title: str  # readonly

    def OnFinish(self) -> bool: ...
    def OnNext(self) -> bool: ...
    def OnBack(self) -> bool: ...
    def DeactivatePage(self) -> None: ...
    def ActivatePage(
        self,
        wizard: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IWizard,
    ) -> None: ...

class LineStyleLabel(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.Label,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
):  # Class
    def __init__(self) -> None: ...

    Color: System.Drawing.Color
    DashStyle: System.Drawing.Drawing2D.DashStyle
    NoDisplayText: str
    ShowLine: bool

class OwnerDrawComboBox(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.ComboBox,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
):  # Class
    def __init__(self) -> None: ...

class OwnerDrawComboBoxItem:  # Class
    def Draw(
        self,
        parent: System.Windows.Forms.Control,
        e: System.Windows.Forms.DrawItemEventArgs,
    ) -> None: ...

class PropertySheet(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    IsDirty: bool  # readonly
    SelectedPageIndex: int

    def AddRange(
        self,
        pages: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IPropertyPage
        ],
    ) -> None: ...
    def Add(
        self,
        page: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IPropertyPage,
    ) -> None: ...

class SeparatorControl(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.Control,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
):  # Class
    def __init__(self) -> None: ...

class SimpleAboutBox(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    AppName: str
    BuildNumber: str
    Copyright: str
    Image: System.Drawing.Image
    PatchNumber: str
    VersionNumber: str

class TitledContainer(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    DisplayRectangle: System.Drawing.Rectangle  # readonly
    Title: str

class Wizard(
    System.Windows.Forms.Layout.IArrangedElement,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IWizard,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self) -> None: ...

    ActivePage: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IWizardPage
    ActivePageIndex: int
    Count: int  # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IWizardPage: ...
    Title: str

    def AddPages(
        self,
        pages: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IWizardPage
        ],
    ) -> None: ...
    def SetButtons(
        self,
        buttons: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.WizardButtons,
    ) -> None: ...
    def AddPage(
        self,
        page: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IWizardPage,
    ) -> None: ...

class WizardButtons(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    EnableBack: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.WizardButtons
    ) = ...  # static # readonly
    EnableCancel: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.WizardButtons
    ) = ...  # static # readonly
    EnableFinish: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.WizardButtons
    ) = ...  # static # readonly
    EnableNext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.WizardButtons
    ) = ...  # static # readonly

class XmlTreeViewControl(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.TreeView,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
):  # Class
    def __init__(self) -> None: ...

    Document: System.Xml.XPath.IXPathNavigable



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import (
    FieldFormat,
    ICustomCommandGroup,
    ICustomUI,
    IDataSource,
    IDataSourceDesigner,
    IDataSourceGraphicsEdit,
    IDataSourceGraphicsParameter,
    IDataSourceTableFormat,
)

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns

class BindingName(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Analysis: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName = (
        ...
    )  # static # readonly
    AuxiliaryMethod: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName
    ) = ...  # static # readonly
    Batch: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName = (
        ...
    )  # static # readonly
    Component: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName = (
        ...
    )  # static # readonly
    DeconvolutionMethod: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName
    ) = ...  # static # readonly
    Hit: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName = (
        ...
    )  # static # readonly
    IdentificationMethod: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName
    ) = ...  # static # readonly
    IonPeak: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName = (
        ...
    )  # static # readonly
    LibrarySearchMethod: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName
    ) = ...  # static # readonly
    Peak: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName = (
        ...
    )  # static # readonly
    PeakQualifier: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName = (
        ...
    )  # static # readonly
    Sample: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName = (
        ...
    )  # static # readonly
    SelectedSample: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName = (
        ...
    )  # static # readonly
    TargetCompound: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName = (
        ...
    )  # static # readonly
    TargetMatchMethod: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName
    ) = ...  # static # readonly
    TargetQualifier: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.BindingName
    ) = ...  # static # readonly

class ComponentSpectrumGraphics(
    System.IDisposable,
    Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.IComponentSpectrumGraphics,
):  # Class
    def __init__(
        self,
        dataSource: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.UnknownsDataSource,
    ) -> None: ...
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        hitId: Optional[int],
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def Dispose(self) -> None: ...

class DataSourceDesigner(
    IDataSourceDesigner,
    System.IDisposable,
    IDataSourceGraphicsEdit,
    IDataSourceTableFormat,
    ICustomUI,
):  # Class
    def __init__(self) -> None: ...

    DataSourceType: System.Type  # readonly

    def GetFieldNames(self, dataName: str) -> List[str]: ...
    def GetDataNames(self) -> List[str]: ...
    def CanExecuteSystemCommand(
        self,
        app: Agilent.MassHunter.ReportBuilder.Application.IApplication,
        systemCommand: str,
        parameter: Any,
        canExecute: bool,
    ) -> bool: ...
    def DefaultFieldFormat(
        self, dataName: str, fieldName: str, format: FieldFormat
    ) -> bool: ...
    def GetGraphicsNames(self) -> List[str]: ...
    def GetDisplayName(self, name: str) -> str: ...
    def GetParameters(self, name: str) -> List[IDataSourceGraphicsParameter]: ...
    def ExecuteSystemCommand(
        self,
        app: Agilent.MassHunter.ReportBuilder.Application.IApplication,
        systemCommand: str,
        parameter: Any,
    ) -> bool: ...
    def Dispose(self) -> None: ...
    def GetCustomCommandGroups(
        self, application: Agilent.MassHunter.ReportBuilder.Application.IApplication
    ) -> List[ICustomCommandGroup]: ...
    def GetCustomUI(self) -> T: ...

class EicPeaksGraphics(
    System.IDisposable,
    Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.IEicPeaksGraphics,
):  # Class
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        x: float,
        y: float,
        width: float,
        height: float,
        parameters: List[System.Collections.Generic.KeyValuePair[str, Any]],
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def Dispose(self) -> None: ...

class ExtractedSpectrumGraphics(
    Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.IExtractedSpectrumGraphics,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataSource: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.UnknownsDataSource,
    ) -> None: ...
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def Dispose(self) -> None: ...

class GraphicsName(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    ComponentSpectrum: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.GraphicsName
    ) = ...  # static # readonly
    EicPeaks: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.GraphicsName = (
        ...
    )  # static # readonly
    ExtractedSpectrum: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.GraphicsName
    ) = ...  # static # readonly
    HitLibrarySpectrum: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.GraphicsName
    ) = ...  # static # readonly
    IonPeaks: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.GraphicsName = (
        ...
    )  # static # readonly
    MolecularStructure: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.GraphicsName
    ) = ...  # static # readonly
    SampleChromatogram: (
        Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.GraphicsName
    ) = ...  # static # readonly

class HitLibrarySpectrumGraphics(
    Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.IHitLibrarySpectrumGraphics,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataSource: Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.UnknownsDataSource,
    ) -> None: ...
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        hitId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def Dispose(self) -> None: ...

class IComponentSpectrumGraphics(object):  # Interface
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        hitId: Optional[int],
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

class IEicPeaksGraphics(object):  # Interface
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

class IExtractedSpectrumGraphics(object):  # Interface
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

class IHitLibrarySpectrumGraphics(object):  # Interface
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        hitId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

class IIonPeaksGraphics(object):  # Interface
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

class IMolecularStructureGraphics(object):  # Interface
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        hitId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

class ISampleChromatogramGraphics(object):  # Interface
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...

class IUnknownsDataSource(IDataSource):  # Interface
    FixedGraphics: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IFixedGraphics
    )
    SelectedSamples: List[
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
    ]

class IonPeaksGraphics(
    System.IDisposable,
    Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.IIonPeaksGraphics,
):  # Class
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        x: float,
        y: float,
        width: float,
        height: float,
        parameters: List[System.Collections.Generic.KeyValuePair[str, Any]],
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def Dispose(self) -> None: ...

class MolecularStructureGraphics(
    Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.IMolecularStructureGraphics,
    System.IDisposable,
):  # Class
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: int,
        componentId: int,
        hitId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def Dispose(self) -> None: ...

class SampleChromatogramGraphics(
    System.IDisposable,
    Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.ISampleChromatogramGraphics,
):  # Class
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    def Dispose(self) -> None: ...

class UnknownsDataSource(
    System.IDisposable,
    Agilent.MassHunter.ReportBuilder.DataSource.Unknowns.IUnknownsDataSource,
    IDataSource,
):  # Class
    def __init__(
        self,
        uiContext: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.UIContext,
    ) -> None: ...

    FixedGraphics: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IFixedGraphics
    )
    SelectedSamples: List[
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
    ]

    def CreateDesigner(self) -> IDataSourceDesigner: ...
    def DrawGraphics(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        x: float,
        y: float,
        width: float,
        height: float,
        name: str,
        parameters: List[System.Collections.Generic.KeyValuePair[str, Any]],
    ) -> None: ...
    def GetFieldCaption(self, dataName: str, fieldName: str) -> str: ...
    def Select(
        self,
        context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext,
        dataBinding: Agilent.MassHunter.ReportBuilder.Template.IDataBinding,
    ) -> List[Any]: ...
    def LocalizeFieldValue(self, dataName: str, fieldName: str, value_: Any) -> str: ...
    def GetFieldFormat(self, dataName: str, fieldName: str) -> str: ...
    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Profile3DView.Remoting

class ISingletonServer(object):  # Interface
    def Open(self, args: List[str]) -> None: ...
    def Ready(self) -> None: ...

class SingletonServer(
    Agilent.MassHunter.Quantitative.Profile3DView.Remoting.ISingletonServer
):  # Class
    def __init__(self) -> None: ...
    def Open(self, args: List[str]) -> None: ...
    def Ready(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import SampleRowID, UnknownsAnalysisDataSet
from .DataFile import DataFileBase
from .UI.Report import GraphicsFileMap, GraphicsFileType, IReportGraphics

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults

class CommandLine:  # Class
    def __init__(self) -> None: ...

    AccountName: str
    AnalysisFile: str
    BatchIDs: str
    BatchPath: str
    CancelEventName: str
    ConnectionTicket: str
    ConsoleTrace: bool
    Culture: str
    Domain: str
    EncryptedPassword: str
    Help: bool
    Local: bool
    Logfile: str
    Method: str
    NoGraphics: bool
    NoLogo: bool
    OutputPath: str
    Password: str
    Printer: str
    PublishFormat: str
    Queue: bool
    ReportFileName: str
    ReporterName: str
    SampleIDs: str
    Server: str
    Template: str
    User: str

class ErrorReportingSettingsSection(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationElementSectionBase
):  # Class
    def __init__(self) -> None: ...

    DumpLogOnNormalExit: bool  # readonly
    EmailAddress: str  # readonly
    Enabled: bool  # readonly

class ExitCode:  # Class
    Canceled: int  # static # readonly
    CommandLineError: int  # static # readonly
    Error: int  # static # readonly
    Ok: int  # static # readonly
    UnknownsError: int  # static # readonly

class GraphicsSizeSettingsSection(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationElementSectionBase
):  # Class
    def __init__(self) -> None: ...
    def GetWidth(self, type: GraphicsFileType, defaultValue: float) -> float: ...
    def GetHeight(self, type: GraphicsFileType, defaultValue: float) -> float: ...

class GraphicsWriter(System.IDisposable):  # Class
    def __init__(
        self,
        generator: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults.ResultsGenerator,
        dataFile: DataFileBase,
        batchID: Optional[int],
        sampleID: Optional[int],
        reportGraphics: IReportGraphics,
        outputPath: str,
        fileMap: GraphicsFileMap,
        allowOverwrite: bool,
    ) -> None: ...
    def Dispose(self) -> None: ...
    def WriteGraphics(self) -> None: ...

class IUnknownsAnalysisDataProvider(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportDataProvider,
    System.IDisposable,
):  # Interface
    AbortEventName: str
    AnalysisFileName: str  # readonly
    AuditTrailDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet
    )  # readonly
    BatchPath: str  # readonly
    IsAuditTrailing: bool  # readonly
    TargetSamples: List[SampleRowID]

    def GetHitsFromMethod(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: Optional[int],
        identificationMethodID: Optional[int],
        table: UnknownsAnalysisDataSet.HitDataTable,
    ) -> int: ...
    def GetPeakQualifier(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        compoundID: Optional[int],
        qualifierID: Optional[int],
        peakID: Optional[int],
        table: UnknownsAnalysisDataSet.PeakQualifierDataTable,
    ) -> int: ...
    def GetIonPeak(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        deconvolutionMethodID: Optional[int],
        componentID: Optional[int],
        ionPeakID: Optional[int],
        table: UnknownsAnalysisDataSet.IonPeakDataTable,
    ) -> int: ...
    def ExecuteReader(
        self, batchID: int, sampleID: int, select: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults.IUnknownsAnalysisDataReader
    ): ...
    def GetSample(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        table: UnknownsAnalysisDataSet.SampleDataTable,
    ) -> int: ...
    def GetTargetCompound(
        self,
        batchId: Optional[int],
        sampleID: Optional[int],
        compoundID: Optional[int],
        table: UnknownsAnalysisDataSet.TargetCompoundDataTable,
    ) -> int: ...
    def GetTargetMatchMethod(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        targetMatchMethodID: Optional[int],
        table: UnknownsAnalysisDataSet.TargetMatchMethodDataTable,
    ) -> int: ...
    def GetTargetQualifier(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        compoundID: Optional[int],
        qualifierID: Optional[int],
        table: UnknownsAnalysisDataSet.TargetQualifierDataTable,
    ) -> int: ...
    def GetPeak(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        compoundID: Optional[int],
        peakID: Optional[int],
        table: UnknownsAnalysisDataSet.PeakDataTable,
    ) -> int: ...
    def GetExactMass(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        deconvolutionMethodID: Optional[int],
        componentID: Optional[int],
        hitID: Optional[int],
        exactMassID: Optional[int],
        table: UnknownsAnalysisDataSet.ExactMassDataTable,
    ) -> int: ...
    def GetAnalysis(self, table: UnknownsAnalysisDataSet.AnalysisDataTable) -> int: ...
    def CreateGraphics(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults.IUnknownsAnalysisGraphics
    ): ...
    def GetBatch(
        self, batchID: Optional[int], table: UnknownsAnalysisDataSet.BatchDataTable
    ) -> int: ...
    def GetAuxiliaryMethod(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        table: UnknownsAnalysisDataSet.AuxiliaryMethodDataTable,
    ) -> int: ...
    def GetLibrarySearchMethod(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        identificationMethodID: Optional[int],
        librarySearchMethodID: Optional[int],
        table: UnknownsAnalysisDataSet.LibrarySearchMethodDataTable,
    ) -> int: ...
    def GetIdentificationMethod(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        identificationMethodID: Optional[int],
        table: UnknownsAnalysisDataSet.IdentificationMethodDataTable,
    ) -> int: ...
    def GetHit(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        deconvolutionMethodID: Optional[int],
        componentID: Optional[int],
        hitID: Optional[int],
        table: UnknownsAnalysisDataSet.HitDataTable,
    ) -> int: ...
    def GetComponent(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        deconvolutionMethodID: Optional[int],
        componentID: Optional[int],
        table: UnknownsAnalysisDataSet.ComponentDataTable,
    ) -> int: ...
    def GetDeconvolutionMethod(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        deconvolutionMethodID: Optional[int],
        table: UnknownsAnalysisDataSet.DeconvolutionMethodDataTable,
    ) -> int: ...

class IUnknownsAnalysisDataReader(System.IDisposable):  # Interface
    def __getitem__(self, name: str) -> Any: ...
    def IsDBNull(self, name: str) -> bool: ...
    def Read(self) -> bool: ...

class IUnknownsAnalysisGraphics(System.IDisposable):  # Interface
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchId: int,
        sampleId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchId: int,
        sampleId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawHitLibrarySpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawHitLibrarySpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawComponentSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawComponentSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def DrawStructure(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    def GetComponentSpectrumRange(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        minx: float,
        maxx: float,
    ) -> None: ...
    def GetSampleChromatogramRange(
        self, batchId: int, sampleId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.GraphicsRange
    ): ...
    @overload
    def DrawIonPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawIonPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
        showTIC: bool,
        showComponent: bool,
        showIons: bool,
        showLabels: bool,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawIonPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
        showTIC: bool,
        showComponent: bool,
        showIons: bool,
        showLabels: bool,
        minX: Optional[float],
        maxX: Optional[float],
        minY: Optional[float],
        maxY: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawEicPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawEicPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
        minX: Optional[float],
        maxX: Optional[float],
        minY: Optional[float],
        maxY: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def GetHitLibrarySpectrumRange(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        minx: float,
        maxx: float,
    ) -> None: ...
    @overload
    def DrawExtractedSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawExtractedSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...

class IUnknownsAnalysisReportBuilderTask(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    System.Xml.Serialization.IXmlSerializable,
    System.IDisposable,
):  # Interface
    AnalysisFile: str
    BatchIDs: List[int]
    BatchPath: str
    Culture: str
    DestinationFile: str
    Local: bool
    ReporterName: str
    SampleIDs: List[int]
    TemplatePath: str

class IUnknownsAnalysisReportMethodTask(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    System.Xml.Serialization.IXmlSerializable,
    System.IDisposable,
):  # Interface
    AnalysisFile: str
    BatchIDs: List[int]
    BatchPath: str
    Culture: str
    MethodPath: str
    OutputPath: str
    ReporterName: str
    SampleIDs: List[int]

class IUnknownsAnalysisReportScriptTask(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    System.Xml.Serialization.IXmlSerializable,
    System.IDisposable,
):  # Interface
    AnalysisFile: str
    BatchIDs: List[int]
    BatchPath: str
    Culture: str
    DestinationFile: str
    MethodPath: str
    OpenPublishedFile: bool
    PrinterName: str
    ReporterName: str
    SampleIDs: List[int]
    TemplatePath: str

class IUnknownsAnalysisReportTask(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    System.Xml.Serialization.IXmlSerializable,
    System.IDisposable,
):  # Interface
    AnalysisFile: str
    BatchID: Optional[int]
    BatchPath: str
    ConnectionTicket: str
    Culture: str
    OutputPath: str
    ReporterName: str
    SampleID: Optional[int]

class ReportBuilderTask(
    System.Xml.Serialization.IXmlSerializable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults.IUnknownsAnalysisReportBuilderTask,
    System.IDisposable,
):  # Class
    def __init__(self) -> None: ...

    Actions: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskAction
    ]  # readonly
    AnalysisFile: str
    BatchIDs: List[int]
    BatchPath: str
    CancelEventName: str
    Context: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskContext
    )
    Culture: str
    DestinationFile: str
    Local: bool
    ProcessingPriority: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.TaskPriority
    )
    ReporterName: str
    SampleIDs: List[int]
    TaskDescription: str  # readonly
    TaskLockName: str  # readonly
    TaskName: str  # readonly
    TemplatePath: str

    def Process(self) -> None: ...
    def GetSchema(self) -> System.Xml.Schema.XmlSchema: ...
    def WriteXml(self, writer: System.Xml.XmlWriter) -> None: ...
    def Dispose(self) -> None: ...
    def ReadXml(self, reader: System.Xml.XmlReader) -> None: ...

class ReportConfiguration:  # Class
    ErrorReportingSettingsSection: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults.ErrorReportingSettingsSection
    )  # readonly
    GraphicsSizeSettingsSection: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults.GraphicsSizeSettingsSection
    )  # readonly
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults.ReportConfiguration
    )  # static # readonly

class ReportMethodTask(
    System.Xml.Serialization.IXmlSerializable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults.IUnknownsAnalysisReportMethodTask,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    System.IDisposable,
):  # Class
    def __init__(self) -> None: ...

    Actions: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskAction
    ]  # readonly
    AnalysisFile: str
    BatchIDs: List[int]
    BatchPath: str
    CancelEventName: str
    Context: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskContext
    )
    Culture: str
    MethodPath: str
    OutputPath: str
    ProcessingPriority: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.TaskPriority
    )
    ReporterName: str
    SampleIDs: List[int]
    TaskDescription: str  # readonly
    TaskLockName: str  # readonly
    TaskName: str  # readonly

    def Process(self) -> None: ...
    def GetSchema(self) -> System.Xml.Schema.XmlSchema: ...
    def WriteXml(self, writer: System.Xml.XmlWriter) -> None: ...
    def Dispose(self) -> None: ...
    def ReadXml(self, reader: System.Xml.XmlReader) -> None: ...

class ReportScriptTask(
    System.Xml.Serialization.IXmlSerializable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults.IUnknownsAnalysisReportScriptTask,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    System.IDisposable,
):  # Class
    def __init__(self) -> None: ...

    Actions: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskAction
    ]  # readonly
    AnalysisFile: str
    BatchIDs: List[int]
    BatchPath: str
    CancelEventName: str
    Context: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskContext
    )
    Culture: str
    DestinationFile: str
    MethodPath: str
    OpenPublishedFile: bool
    PrinterName: str
    ProcessingPriority: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.TaskPriority
    )
    ReporterName: str
    SampleIDs: List[int]
    TaskDescription: str  # readonly
    TaskLockName: str  # readonly
    TaskName: str  # readonly
    TemplatePath: str

    def Process(self) -> None: ...
    def GetSchema(self) -> System.Xml.Schema.XmlSchema: ...
    def WriteXml(self, writer: System.Xml.XmlWriter) -> None: ...
    def Dispose(self) -> None: ...
    def ReadXml(self, reader: System.Xml.XmlReader) -> None: ...

class ResultsGenerator(System.IDisposable):  # Class
    def __init__(
        self,
        batchPath: str,
        analysisFile: str,
        outputPath: str,
        noGraphics: bool,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

    ResultFileName: str = ...  # static # readonly

    BatchID: Optional[int]
    CancelEventName: str
    ReporterName: str
    SampleID: Optional[int]

    def Run(self) -> None: ...
    def Dispose(self) -> None: ...

class UnknownsAnalysisReportTask(
    System.Xml.Serialization.IXmlSerializable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportResults.IUnknownsAnalysisReportTask,
):  # Class
    def __init__(self) -> None: ...

    AnalysisFile: str
    BatchID: Optional[int]
    BatchPath: str
    CancelEventName: str
    ConnectionTicket: str
    Context: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskContext
    )
    Culture: str
    OutputPath: str
    ProcessingPriority: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.TaskPriority
    )
    ReporterName: str
    SampleID: Optional[int]

    def Dispose(self) -> None: ...
